##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 8: Interval Estimation                                         #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################



######################################
# 8.1 Population Mean: sigma Known   #
######################################


# Chapter 7: Lloyds example
sigma <- 20
n <- 100
sigma.xbar <- sigma/sqrt(n)
sigma.xbar 
alpha <- 0.05  # 95% significance level
qnorm(alpha/2)
z.alpha <- qnorm(1 - alpha/2)
z.alpha

# Margin of Error 
margin.error <- z.alpha * sigma.xbar
c(-margin.error, margin.error)

#  100(1 - alpha)%  confidence coefficient for population mean
xbar <- 82
c(xbar - margin.error, xbar + margin.error)


# if you read excel 
# library(readxl)
LloydS <- read_excel("data/chap08/LloydS.xlsx")

# if you read csv
# LloydS <- read.csv("data/chap08/LloydS.csv")
# str(LloydS)
# LloydS$"Amount Spent" <- LloydS$Amount.Spent

str(LloydS)
head(LloydS)
tail(LloydS)
N <- length(LloydS$"Amount Spent")
N
id <- sample(1:N, 30)
xbar <- mean(LloydS$"Amount Spent"[id])
c(xbar - margin.error, xbar + margin.error)



# suppose true mean mu = mean(LloydS$"Amount Spent")
count <- numeric(10000)
mu <- mean(LloydS$"Amount Spent")
mu
n <- 30
alpha <- 0.05  # 95% significance level
z.alpha <- qnorm(1 - alpha/2)

for(i in 1:10000){
 xbar <- mean(LloydS$"Amount Spent"[sample(1:N, n)])
 sigma.xbar <- sigma/sqrt(n)
 margin.error <- z.alpha * sigma.xbar
 lower <- xbar - margin.error
 upper <- xbar + margin.error
 if(lower <= mu & mu <= upper) count[i] <- 1
}
mean(count)

########################################
# 8.2 Population Mean: sigma unKnown   #
########################################
s <- sd(LloydS$"Amount Spent"[sample(1:N, n)])
sigma.xbar <- s/sqrt(n)

########################################
# 8.3 Determining the sample size      #
########################################
ceiling((z.alpha^2 * sigma^2)/ margin.error)

